# Xcapi

## Description

Python library for communicating with the xray core grpc api

Follow xray core version updates

Use python 3.12

## Install
```bash
pip install xcapi
```
## Usage
[Example](https://github.com/Acer-Platanoides/xcapi/tree/main/test)